Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/render/extern/include/RE_render_ext.h')
-rw-r--r--source/blender/render/extern/include/RE_render_ext.h49
1 files changed, 35 insertions, 14 deletions
diff --git a/source/blender/render/extern/include/RE_render_ext.h b/source/blender/render/extern/include/RE_render_ext.h
index 6e1f128b7a5..2b5d0ca4e14 100644
--- a/source/blender/render/extern/include/RE_render_ext.h
+++ b/source/blender/render/extern/include/RE_render_ext.h
@@ -42,30 +42,51 @@ struct ImagePool;
struct MTex;
struct Scene;
-/* particle.c, effect.c, editmesh_modes.c and brush.c, returns 1 if rgb, 0 otherwise */
-int externtex(struct MTex *mtex, const float vec[3], float *tin, float *tr, float *tg, float *tb, float *ta, const int thread, struct ImagePool *pool, const bool skip_load_image);
-
-/* particle.c */
+/* render_texture.c */
+/* used by particle.c, effect.c, editmesh_modes.c and brush.c, returns 1 if rgb, 0 otherwise */
+int externtex(
+ struct MTex *mtex, const float vec[3], float *tin, float *tr, float *tg, float *tb, float *ta,
+ const int thread, struct ImagePool *pool, const bool skip_load_image, const bool texnode_preview);
void texture_rgb_blend(float in[3], const float tex[3], const float out[3], float fact, float facg, int blendtype);
float texture_value_blend(float tex, float out, float fact, float facg, int blendtype);
-/* node_composite.c */
-void ibuf_sample(struct ImBuf *ibuf, float fx, float fy, float dx, float dy, float result[4]);
-void antialias_tagbuf(int xsize, int ysize, char *rectmove);
+void RE_texture_rng_init(void);
+void RE_texture_rng_exit(void);
-/* dynamicpaint.c */
-struct Material *RE_init_sample_material(struct Material *orig_mat, struct Scene *scene);
-void RE_free_sample_material(struct Material *mat);
+struct Material *RE_sample_material_init(struct Material *orig_mat, struct Scene *scene);
+void RE_sample_material_free(struct Material *mat);
void RE_sample_material_color(
struct Material *mat, float color[3], float *alpha, const float volume_co[3], const float surface_co[3],
int tri_index, struct DerivedMesh *orcoDm, struct Object *ob);
-/* pointdensity.c */
+/* imagetexture.c */
+void ibuf_sample(struct ImBuf *ibuf, float fx, float fy, float dx, float dy, float result[4]);
+
+/* zbuf.c */
+void antialias_tagbuf(int xsize, int ysize, char *rectmove);
+
+/* pointdensity.c */
struct PointDensity;
-void RE_sample_point_density(struct Scene *scene, struct PointDensity *pd, int resolution, float *values);
+void RE_point_density_cache(
+ struct Scene *scene,
+ struct PointDensity *pd,
+ const bool use_render_params);
+
+void RE_point_density_minmax(
+ struct Scene *scene,
+ struct PointDensity *pd,
+ const bool use_render_params,
+ float r_min[3], float r_max[3]);
+
+void RE_point_density_sample(
+ struct Scene *scene,
+ struct PointDensity *pd,
+ const int resolution,
+ const bool use_render_params,
+ float *values);
+
+void RE_point_density_free(struct PointDensity *pd);
-void RE_init_texture_rng(void);
-void RE_exit_texture_rng(void);
#endif /* __RE_RENDER_EXT_H__ */